@@ -67,7 +67,7 @@ async def handle_args(args: argparse.Namespace):
     print_args['simpcity_password'] = '!REDACTED!'
     print_args['jdownloader_password'] = '!REDACTED!'
 
-    await log("Creating Config")
+    logging.debug("Creating Config")
     cmd_args = Namespace(**vars(args)).__dict__
     await create_config(args.config_file, print_args)
 
@@ -196,7 +196,6 @@ def main(args=None):
         loop = asyncio.get_event_loop()
         loop.run_until_complete(director(args))
         loop.run_until_complete(asyncio.sleep(5))
-        loop.close()
     except RuntimeError:
         pass
 
