@@ -1,4 +1,5 @@
 import asyncio
+import logging
 from typing import Dict
 
 import aiofiles
@@ -75,7 +76,8 @@ class ScrapeMapper:
 
         self.jdownloader_agent = None
 
-        self.jpgchurch_limiter = AsyncRateLimiter(10)
+        self.jpgchurch_limiter = AsyncRateLimiter(15)
+        self.jpgchurch_semaphore = asyncio.Semaphore(5)
         self.bunkr_limiter = AsyncRateLimiter(15)
         self.forum_limiter = asyncio.Semaphore(4)
         self.semaphore = asyncio.Semaphore(1)
@@ -257,8 +259,9 @@ class ScrapeMapper:
         if not self.sharex_crawler:
             self.sharex_crawler = ShareXCrawler(include_id=self.include_id)
         if "jpg.church" in url.host and sharex_session.client.ratelimit > 19:
-            async with self.jpgchurch_limiter:
-                domain_obj = await self.sharex_crawler.fetch(sharex_session, url)
+            async with self.jpgchurch_semaphore:
+                async with self.jpgchurch_limiter:
+                    domain_obj = await self.sharex_crawler.fetch(sharex_session, url)
         else:
             domain_obj = await self.sharex_crawler.fetch(sharex_session, url)
         if title:
@@ -343,7 +346,8 @@ class ScrapeMapper:
                     raise Exception("Blacklisted META")
                 await log("Sending " + str(url_to_map) + " to JDownloader")
                 self.jdownloader_agent.linkgrabber.add_links([{"autostart": False, "links": str(url_to_map)}])
-            except:
+            except Exception as e:
+                logging.debug(e)
                 await log("Failed to send " + str(url_to_map) + " to JDownloader")
         else:
             await log(str(url_to_map) + " is not supported currently.")
